@@ -11,7 +11,7 @@ from jsonschema import validate
 from pydantic import conlist
 from smart_open import open as s_open
 
-from .schema_types import AllTypes, Array, JSFEnum, JSFTuple, Object, PrimativeTypes, Primitives
+from .schema_types import AllTypes, Array, JSFEnum, JSFTuple, Object, PrimativeTypes, Primitives, AnyOf
 
 logger = logging.getLogger()
 faker = Faker()
@@ -72,9 +72,10 @@ class JSF:
     def __is_field_nullable(self, schema: Dict[str, Any]) -> Tuple[str, bool]:
         item_type = schema.get("type")
         if isinstance(item_type, list):
-            if "null" in item_type and len(set(item_type)) == 2:
-                deepcopy(item_type).remove("null")
-                return item_type[0], True
+            if "null" in item_type and len(set(item_type)) >= 2:
+                item_type_deep_copy = deepcopy(item_type)
+                item_type_deep_copy.remove("null")
+                return random.choice(item_type_deep_copy), True
             raise TypeError  # pragma: no cover - not currently supporting other types TODO
         return item_type, False
 
@@ -112,6 +113,11 @@ class JSF:
             cls.name = name
             cls.path = path
             return cls
+        elif "anyOf" in schema:
+            schemas = []
+            for d in schema["anyOf"]:
+                schemas.append(self.__parse_definition(name, path, d))
+            return AnyOf(schemas=schemas)
         else:
             raise ValueError(f"Cannot parse schema {repr(schema)}")  # pragma: no cover
 
