@@ -10,7 +10,7 @@ _types = {"string": str, "integer": int, "number": float}
 
 
 class JSFEnum(BaseSchema):
-    enum: Optional[List[Union[str, int, float]]] = []
+    enum: Optional[List[Union[str, int, float, None]]] = []
 
     def generate(self, context: Dict[str, Any]) -> Optional[Union[str, int, float]]:
         try:
@@ -26,3 +26,6 @@ class JSFEnum(BaseSchema):
         _type = Enum(value=self._get_unique_name(context), type=base, names={str(v): v for v in self.enum})
         context["__internal__"][_type.__name__] = _type
         return self.to_pydantic(context, _type)
+
+    class Config:
+        smart_union = True
