@@ -45,7 +45,8 @@ class Number(BaseSchema):
 
 class Integer(Number):
     def generate(self, context: Dict[str, Any]) -> Optional[int]:
-        return int(super().generate(context))
+        n = super().generate(context)
+        return int(n) if n else n
 
     def model(self, context: Dict[str, Any]):
         return self.to_pydantic(context, int)
